# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/system_modes_msgs/srv/get_available_modes.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/system_modes_msgs/srv/get_available_modes.proto\x12\x32make87_messages_ros2.rolling.system_modes_msgs.srv\"\x1a\n\x18GetAvailableModesRequest\"4\n\x19GetAvailableModesResponse\x12\x17\n\x0f\x61vailable_modes\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.system_modes_msgs.srv.get_available_modes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETAVAILABLEMODESREQUEST']._serialized_start=132
  _globals['_GETAVAILABLEMODESREQUEST']._serialized_end=158
  _globals['_GETAVAILABLEMODESRESPONSE']._serialized_start=160
  _globals['_GETAVAILABLEMODESRESPONSE']._serialized_end=212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_time_utc.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import utc_std_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_utc__std__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_time_utc.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a;make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/utc_std.proto\"\xce\x02\n\rUBXNavTimeUTC\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04itow\x18\x02 \x01(\r\x12\r\n\x05t_acc\x18\x03 \x01(\r\x12\x0c\n\x04nano\x18\x04 \x01(\x05\x12\x0c\n\x04year\x18\x05 \x01(\x05\x12\r\n\x05month\x18\x06 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x07 \x01(\x05\x12\x0c\n\x04hour\x18\x08 \x01(\x05\x12\x0b\n\x03min\x18\t \x01(\x05\x12\x0b\n\x03sec\x18\n \x01(\x05\x12\x11\n\tvalid_tow\x18\x0b \x01(\x08\x12\x11\n\tvalid_wkn\x18\x0c \x01(\x08\x12\x11\n\tvalid_utc\x18\r \x01(\x08\x12\x46\n\x07utc_std\x18\x0e \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.UtcStdb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_nav_time_utc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXNAVTIMEUTC']._serialized_start=235
  _globals['_UBXNAVTIMEUTC']._serialized_end=569
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/msg/route_offset.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_position_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__position__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/marti_nav_msgs/msg/route_offset.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x44make87_messages_ros2/rolling/marti_nav_msgs/msg/route_position.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf5\x01\n\x0bRouteOffset\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12K\n\rrelative_pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12V\n\x0eroute_position\x18\x03 \x01(\x0b\x32>.make87_messages_ros2.rolling.marti_nav_msgs.msg.RoutePositionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.msg.route_offset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROUTEOFFSET']._serialized_start=305
  _globals['_ROUTEOFFSET']._serialized_end=550
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.tuw_multi_robot_msgs.msg import route_precondition_pb2 as _route_precondition_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RouteSegment(_message.Message):
    __slots__ = ("header", "segment_id", "preconditions", "start", "end", "width")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SEGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    PRECONDITIONS_FIELD_NUMBER: _ClassVar[int]
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    segment_id: int
    preconditions: _containers.RepeatedCompositeFieldContainer[_route_precondition_pb2.RoutePrecondition]
    start: _pose_pb2.Pose
    end: _pose_pb2.Pose
    width: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., segment_id: _Optional[int] = ..., preconditions: _Optional[_Iterable[_Union[_route_precondition_pb2.RoutePrecondition, _Mapping]]] = ..., start: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., end: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., width: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Weight(_message.Message):
    __slots__ = ("header", "stamp", "stable", "overload", "weight", "unit")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    STABLE_FIELD_NUMBER: _ClassVar[int]
    OVERLOAD_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    stamp: _time_pb2.Time
    stable: bool
    overload: bool
    weight: float
    unit: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., stable: bool = ..., overload: bool = ..., weight: _Optional[float] = ..., unit: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrEthTx(_message.Message):
    __slots__ = ("header", "xcp_format_version", "scan_index", "tcp_size", "xcp_scan_type", "look_index", "mmr_scan_index", "target_report_host_speed", "target_report_host_yaw_rate", "xcp_timestamp", "release_revision", "promote_revision", "field_revision", "target_report_count", "target_report_range", "target_report_range_rate", "target_report_theta", "target_report_amplitude")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    XCP_FORMAT_VERSION_FIELD_NUMBER: _ClassVar[int]
    SCAN_INDEX_FIELD_NUMBER: _ClassVar[int]
    TCP_SIZE_FIELD_NUMBER: _ClassVar[int]
    XCP_SCAN_TYPE_FIELD_NUMBER: _ClassVar[int]
    LOOK_INDEX_FIELD_NUMBER: _ClassVar[int]
    MMR_SCAN_INDEX_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_HOST_SPEED_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_HOST_YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    XCP_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    RELEASE_REVISION_FIELD_NUMBER: _ClassVar[int]
    PROMOTE_REVISION_FIELD_NUMBER: _ClassVar[int]
    FIELD_REVISION_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_COUNT_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_RANGE_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_RANGE_RATE_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_THETA_FIELD_NUMBER: _ClassVar[int]
    TARGET_REPORT_AMPLITUDE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    xcp_format_version: int
    scan_index: int
    tcp_size: int
    xcp_scan_type: int
    look_index: int
    mmr_scan_index: int
    target_report_host_speed: float
    target_report_host_yaw_rate: float
    xcp_timestamp: int
    release_revision: int
    promote_revision: int
    field_revision: int
    target_report_count: int
    target_report_range: _containers.RepeatedScalarFieldContainer[float]
    target_report_range_rate: _containers.RepeatedScalarFieldContainer[float]
    target_report_theta: _containers.RepeatedScalarFieldContainer[float]
    target_report_amplitude: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., xcp_format_version: _Optional[int] = ..., scan_index: _Optional[int] = ..., tcp_size: _Optional[int] = ..., xcp_scan_type: _Optional[int] = ..., look_index: _Optional[int] = ..., mmr_scan_index: _Optional[int] = ..., target_report_host_speed: _Optional[float] = ..., target_report_host_yaw_rate: _Optional[float] = ..., xcp_timestamp: _Optional[int] = ..., release_revision: _Optional[int] = ..., promote_revision: _Optional[int] = ..., field_revision: _Optional[int] = ..., target_report_count: _Optional[int] = ..., target_report_range: _Optional[_Iterable[float]] = ..., target_report_range_rate: _Optional[_Iterable[float]] = ..., target_report_theta: _Optional[_Iterable[float]] = ..., target_report_amplitude: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/sig_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sig_flags_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__ubx__msgs_dot_msg_dot_sig__flags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ublox_ubx_msgs/msg/sig_data.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\x1a?make87_messages_ros2/rolling/ublox_ubx_msgs/msg/sig_flags.proto\"\xf3\x01\n\x07SigData\x12\x0f\n\x07gnss_id\x18\x01 \x01(\r\x12\r\n\x05sv_id\x18\x02 \x01(\r\x12\x0e\n\x06sig_id\x18\x03 \x01(\r\x12\x0f\n\x07\x66req_id\x18\x04 \x01(\r\x12\x0e\n\x06pr_res\x18\x05 \x01(\x05\x12\x0b\n\x03\x63no\x18\x06 \x01(\r\x12\x13\n\x0bquality_ind\x18\x07 \x01(\r\x12\x13\n\x0b\x63orr_source\x18\x08 \x01(\r\x12\x12\n\niono_model\x18\t \x01(\r\x12L\n\tsig_flags\x18\n \x01(\x0b\x32\x39.make87_messages_ros2.rolling.ublox_ubx_msgs.msg.SigFlagsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.sig_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SIGDATA']._serialized_start=181
  _globals['_SIGDATA']._serialized_end=424
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Container(_message.Message):
    __slots__ = ("state_id", "path", "children", "outcomes", "transitions", "type", "autonomy")
    STATE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    OUTCOMES_FIELD_NUMBER: _ClassVar[int]
    TRANSITIONS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTONOMY_FIELD_NUMBER: _ClassVar[int]
    state_id: int
    path: str
    children: _containers.RepeatedScalarFieldContainer[str]
    outcomes: _containers.RepeatedScalarFieldContainer[str]
    transitions: _containers.RepeatedScalarFieldContainer[str]
    type: int
    autonomy: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, state_id: _Optional[int] = ..., path: _Optional[str] = ..., children: _Optional[_Iterable[str]] = ..., outcomes: _Optional[_Iterable[str]] = ..., transitions: _Optional[_Iterable[str]] = ..., type: _Optional[int] = ..., autonomy: _Optional[_Iterable[int]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavCLOCK(_message.Message):
    __slots__ = ("i_tow", "clk_b", "clk_d", "t_acc", "f_acc")
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    CLK_B_FIELD_NUMBER: _ClassVar[int]
    CLK_D_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    F_ACC_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    clk_b: int
    clk_d: int
    t_acc: int
    f_acc: int
    def __init__(self, i_tow: _Optional[int] = ..., clk_b: _Optional[int] = ..., clk_d: _Optional[int] = ..., t_acc: _Optional[int] = ..., f_acc: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class HnrPVT(_message.Message):
    __slots__ = ("i_tow", "year", "month", "day", "hour", "min", "sec", "valid", "nano", "gps_fix", "flags", "reserved0", "lon", "lat", "height", "h_msl", "g_speed", "speed", "head_mot", "head_veh", "h_acc", "v_acc", "s_acc", "head_acc", "reserved1")
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SEC_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    NANO_FIELD_NUMBER: _ClassVar[int]
    GPS_FIX_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    H_MSL_FIELD_NUMBER: _ClassVar[int]
    G_SPEED_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    HEAD_MOT_FIELD_NUMBER: _ClassVar[int]
    HEAD_VEH_FIELD_NUMBER: _ClassVar[int]
    H_ACC_FIELD_NUMBER: _ClassVar[int]
    V_ACC_FIELD_NUMBER: _ClassVar[int]
    S_ACC_FIELD_NUMBER: _ClassVar[int]
    HEAD_ACC_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    year: int
    month: int
    day: int
    hour: int
    min: int
    sec: int
    valid: int
    nano: int
    gps_fix: int
    flags: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    lon: int
    lat: int
    height: int
    h_msl: int
    g_speed: int
    speed: int
    head_mot: int
    head_veh: int
    h_acc: int
    v_acc: int
    s_acc: int
    head_acc: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, i_tow: _Optional[int] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., min: _Optional[int] = ..., sec: _Optional[int] = ..., valid: _Optional[int] = ..., nano: _Optional[int] = ..., gps_fix: _Optional[int] = ..., flags: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ..., lon: _Optional[int] = ..., lat: _Optional[int] = ..., height: _Optional[int] = ..., h_msl: _Optional[int] = ..., g_speed: _Optional[int] = ..., speed: _Optional[int] = ..., head_mot: _Optional[int] = ..., head_veh: _Optional[int] = ..., h_acc: _Optional[int] = ..., v_acc: _Optional[int] = ..., s_acc: _Optional[int] = ..., head_acc: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import motion_sequence_request_pb2 as _motion_sequence_request_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import motion_sequence_response_pb2 as _motion_sequence_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMotionSequenceRequest(_message.Message):
    __slots__ = ("request",)
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _motion_sequence_request_pb2.MotionSequenceRequest
    def __init__(self, request: _Optional[_Union[_motion_sequence_request_pb2.MotionSequenceRequest, _Mapping]] = ...) -> None: ...

class GetMotionSequenceResponse(_message.Message):
    __slots__ = ("response",)
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: _motion_sequence_response_pb2.MotionSequenceResponse
    def __init__(self, response: _Optional[_Union[_motion_sequence_response_pb2.MotionSequenceResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/cartographer_ros_msgs/srv/submap_query.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_humble_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import submap_texture_pb2 as make87__messages__ros2_dot_humble_dot_cartographer__ros__msgs_dot_msg_dot_submap__texture__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/cartographer_ros_msgs/srv/submap_query.proto\x12\x35make87_messages_ros2.humble.cartographer_ros_msgs.srv\x1a!make87_messages/core/header.proto\x1aKmake87_messages_ros2/humble/cartographer_ros_msgs/msg/status_response.proto\x1aJmake87_messages_ros2/humble/cartographer_ros_msgs/msg/submap_texture.proto\"o\n\x12SubmapQueryRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\rtrajectory_id\x18\x02 \x01(\x05\x12\x14\n\x0csubmap_index\x18\x03 \x01(\x05\"\x8a\x02\n\x13SubmapQueryResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12U\n\x06status\x18\x02 \x01(\x0b\x32\x45.make87_messages_ros2.humble.cartographer_ros_msgs.msg.StatusResponse\x12\x16\n\x0esubmap_version\x18\x03 \x01(\x05\x12V\n\x08textures\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.humble.cartographer_ros_msgs.msg.SubmapTextureb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.cartographer_ros_msgs.srv.submap_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SUBMAPQUERYREQUEST']._serialized_start=319
  _globals['_SUBMAPQUERYREQUEST']._serialized_end=430
  _globals['_SUBMAPQUERYRESPONSE']._serialized_start=433
  _globals['_SUBMAPQUERYRESPONSE']._serialized_end=699
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/lane_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import speed_limited_lane_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_speed__limited__lane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/lane_states.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1aHmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/speed_limited_lane.proto\"\x8f\x01\n\nLaneStates\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63losed_lanes\x18\x02 \x03(\x04\x12W\n\x0cspeed_limits\x18\x03 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.SpeedLimitedLaneb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.lane_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LANESTATES']._serialized_start=193
  _globals['_LANESTATES']._serialized_end=336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/itinerary_set.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import route_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/itinerary_set.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1a=make87_messages_ros2/rolling/rmf_traffic_msgs/msg/route.proto\"\xaf\x01\n\x0cItinerarySet\x12\x13\n\x0bparticipant\x18\x01 \x01(\x04\x12\x0c\n\x04plan\x18\x02 \x01(\x04\x12K\n\titinerary\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Route\x12\x14\n\x0cstorage_base\x18\x04 \x01(\x04\x12\x19\n\x11itinerary_version\x18\x05 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.itinerary_set_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ITINERARYSET']._serialized_start=188
  _globals['_ITINERARYSET']._serialized_end=363
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ds_dbw_msgs/msg/driver_assist.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ds_dbw_msgs.msg import decel_src_pb2 as make87__messages__ros2_dot_humble_dot_ds__dbw__msgs_dot_msg_dot_decel__src__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/ds_dbw_msgs/msg/driver_assist.proto\x12+make87_messages_ros2.humble.ds_dbw_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/ds_dbw_msgs/msg/decel_src.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xa3\x04\n\x0c\x44riverAssist\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\r\n\x05\x64\x65\x63\x65l\x18\x03 \x01(\x02\x12H\n\tdecel_src\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.humble.ds_dbw_msgs.msg.DecelSrc\x12\x12\n\nfcw_active\x18\x05 \x01(\x08\x12\x13\n\x0b\x66\x63w_enabled\x18\x06 \x01(\x08\x12\x12\n\naeb_active\x18\x07 \x01(\x08\x12\x15\n\raeb_precharge\x18\x08 \x01(\x08\x12\x13\n\x0b\x61\x65\x62_enabled\x18\t \x01(\x08\x12\x13\n\x0b\x61\x63\x63_braking\x18\n \x01(\x08\x12\x13\n\x0b\x61\x63\x63_enabled\x18\x0b \x01(\x08\x12\x14\n\x0c\x62lis_l_alert\x18\x0c \x01(\x08\x12\x16\n\x0e\x62lis_l_enabled\x18\r \x01(\x08\x12\x14\n\x0c\x62lis_r_alert\x18\x0e \x01(\x08\x12\x16\n\x0e\x62lis_r_enabled\x18\x0f \x01(\x08\x12\x13\n\x0b\x63ta_l_alert\x18\x10 \x01(\x08\x12\x15\n\rcta_l_enabled\x18\x11 \x01(\x08\x12\x13\n\x0b\x63ta_r_alert\x18\x12 \x01(\x08\x12\x15\n\rcta_r_enabled\x18\x13 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ds_dbw_msgs.msg.driver_assist_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DRIVERASSIST']._serialized_start=264
  _globals['_DRIVERASSIST']._serialized_end=811
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.smacc2_msgs.msg import smacc_event_generator_pb2 as _smacc_event_generator_pb2
from make87_messages_ros2.humble.smacc2_msgs.msg import smacc_orthogonal_pb2 as _smacc_orthogonal_pb2
from make87_messages_ros2.humble.smacc2_msgs.msg import smacc_state_reactor_pb2 as _smacc_state_reactor_pb2
from make87_messages_ros2.humble.smacc2_msgs.msg import smacc_transition_pb2 as _smacc_transition_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccState(_message.Message):
    __slots__ = ("header", "index", "name", "children_states", "level", "transitions", "orthogonals", "state_reactors", "event_generators")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_STATES_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    TRANSITIONS_FIELD_NUMBER: _ClassVar[int]
    ORTHOGONALS_FIELD_NUMBER: _ClassVar[int]
    STATE_REACTORS_FIELD_NUMBER: _ClassVar[int]
    EVENT_GENERATORS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    index: int
    name: str
    children_states: _containers.RepeatedScalarFieldContainer[str]
    level: int
    transitions: _containers.RepeatedCompositeFieldContainer[_smacc_transition_pb2.SmaccTransition]
    orthogonals: _containers.RepeatedCompositeFieldContainer[_smacc_orthogonal_pb2.SmaccOrthogonal]
    state_reactors: _containers.RepeatedCompositeFieldContainer[_smacc_state_reactor_pb2.SmaccStateReactor]
    event_generators: _containers.RepeatedCompositeFieldContainer[_smacc_event_generator_pb2.SmaccEventGenerator]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., index: _Optional[int] = ..., name: _Optional[str] = ..., children_states: _Optional[_Iterable[str]] = ..., level: _Optional[int] = ..., transitions: _Optional[_Iterable[_Union[_smacc_transition_pb2.SmaccTransition, _Mapping]]] = ..., orthogonals: _Optional[_Iterable[_Union[_smacc_orthogonal_pb2.SmaccOrthogonal, _Mapping]]] = ..., state_reactors: _Optional[_Iterable[_Union[_smacc_state_reactor_pb2.SmaccStateReactor, _Mapping]]] = ..., event_generators: _Optional[_Iterable[_Union[_smacc_event_generator_pb2.SmaccEventGenerator, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LaneletMapCellMetaData(_message.Message):
    __slots__ = ("cell_id", "min_x", "max_x", "min_y", "max_y")
    CELL_ID_FIELD_NUMBER: _ClassVar[int]
    MIN_X_FIELD_NUMBER: _ClassVar[int]
    MAX_X_FIELD_NUMBER: _ClassVar[int]
    MIN_Y_FIELD_NUMBER: _ClassVar[int]
    MAX_Y_FIELD_NUMBER: _ClassVar[int]
    cell_id: str
    min_x: float
    max_x: float
    min_y: float
    max_y: float
    def __init__(self, cell_id: _Optional[str] = ..., min_x: _Optional[float] = ..., max_x: _Optional[float] = ..., min_y: _Optional[float] = ..., max_y: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgMSG(_message.Message):
    __slots__ = ("msg_class", "msg_id", "rate")
    MSG_CLASS_FIELD_NUMBER: _ClassVar[int]
    MSG_ID_FIELD_NUMBER: _ClassVar[int]
    RATE_FIELD_NUMBER: _ClassVar[int]
    msg_class: int
    msg_id: int
    rate: int
    def __init__(self, msg_class: _Optional[int] = ..., msg_id: _Optional[int] = ..., rate: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.micro_ros_msgs.msg import node_pb2 as _node_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Graph(_message.Message):
    __slots__ = ("nodes",)
    NODES_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    def __init__(self, nodes: _Optional[_Iterable[_Union[_node_pb2.Node, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class WarmStartRequest(_message.Message):
    __slots__ = ("reset_type",)
    RESET_TYPE_FIELD_NUMBER: _ClassVar[int]
    reset_type: int
    def __init__(self, reset_type: _Optional[int] = ...) -> None: ...

class WarmStartResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviorLog(_message.Message):
    __slots__ = ("text", "status_code")
    TEXT_FIELD_NUMBER: _ClassVar[int]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    text: str
    status_code: int
    def __init__(self, text: _Optional[str] = ..., status_code: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NodeDetailsRequest(_message.Message):
    __slots__ = ("node",)
    NODE_FIELD_NUMBER: _ClassVar[int]
    node: str
    def __init__(self, node: _Optional[str] = ...) -> None: ...

class NodeDetailsResponse(_message.Message):
    __slots__ = ("subscribing", "publishing", "services")
    SUBSCRIBING_FIELD_NUMBER: _ClassVar[int]
    PUBLISHING_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    subscribing: _containers.RepeatedScalarFieldContainer[str]
    publishing: _containers.RepeatedScalarFieldContainer[str]
    services: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, subscribing: _Optional[_Iterable[str]] = ..., publishing: _Optional[_Iterable[str]] = ..., services: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_pb2 as _planning_scene_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplyPlanningSceneRequest(_message.Message):
    __slots__ = ("scene",)
    SCENE_FIELD_NUMBER: _ClassVar[int]
    scene: _planning_scene_pb2.PlanningScene
    def __init__(self, scene: _Optional[_Union[_planning_scene_pb2.PlanningScene, _Mapping]] = ...) -> None: ...

class ApplyPlanningSceneResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.as2_msgs.msg import control_mode_pb2 as _control_mode_pb2
from make87_messages_ros2.humble.as2_msgs.msg import platform_status_pb2 as _platform_status_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlatformInfo(_message.Message):
    __slots__ = ("header", "ros2_header", "connected", "armed", "offboard", "status", "current_control_mode")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_FIELD_NUMBER: _ClassVar[int]
    ARMED_FIELD_NUMBER: _ClassVar[int]
    OFFBOARD_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_CONTROL_MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    connected: bool
    armed: bool
    offboard: bool
    status: _platform_status_pb2.PlatformStatus
    current_control_mode: _control_mode_pb2.ControlMode
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., connected: bool = ..., armed: bool = ..., offboard: bool = ..., status: _Optional[_Union[_platform_status_pb2.PlatformStatus, _Mapping]] = ..., current_control_mode: _Optional[_Union[_control_mode_pb2.ControlMode, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LoadDatabaseRequest(_message.Message):
    __slots__ = ("database_path", "clear")
    DATABASE_PATH_FIELD_NUMBER: _ClassVar[int]
    CLEAR_FIELD_NUMBER: _ClassVar[int]
    database_path: str
    clear: bool
    def __init__(self, database_path: _Optional[str] = ..., clear: bool = ...) -> None: ...

class LoadDatabaseResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MountingPositionF(_message.Message):
    __slots__ = ("header", "yaw_angle", "pitch_angle", "roll_angle", "x_position", "y_position", "z_position")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    YAW_ANGLE_FIELD_NUMBER: _ClassVar[int]
    PITCH_ANGLE_FIELD_NUMBER: _ClassVar[int]
    ROLL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    X_POSITION_FIELD_NUMBER: _ClassVar[int]
    Y_POSITION_FIELD_NUMBER: _ClassVar[int]
    Z_POSITION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    yaw_angle: float
    pitch_angle: float
    roll_angle: float
    x_position: float
    y_position: float
    z_position: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., yaw_angle: _Optional[float] = ..., pitch_angle: _Optional[float] = ..., roll_angle: _Optional[float] = ..., x_position: _Optional[float] = ..., y_position: _Optional[float] = ..., z_position: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plotjuggler_msgs/msg/data_points.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.plotjuggler_msgs.msg import data_point_pb2 as make87__messages__ros2_dot_jazzy_dot_plotjuggler__msgs_dot_msg_dot_data__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/plotjuggler_msgs/msg/data_points.proto\x12/make87_messages_ros2.jazzy.plotjuggler_msgs.msg\x1a@make87_messages_ros2/jazzy/plotjuggler_msgs/msg/data_point.proto\"r\n\nDataPoints\x12\x17\n\x0f\x64ictionary_uuid\x18\x01 \x01(\r\x12K\n\x07samples\x18\x02 \x03(\x0b\x32:.make87_messages_ros2.jazzy.plotjuggler_msgs.msg.DataPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plotjuggler_msgs.msg.data_points_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DATAPOINTS']._serialized_start=184
  _globals['_DATAPOINTS']._serialized_end=298
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/srv/open_snapshot_stream.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import snapshot_stream_parameters_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_snapshot__stream__parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/py_trees_ros_interfaces/srv/open_snapshot_stream.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.srv\x1aYmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/snapshot_stream_parameters.proto\"\x97\x01\n\x19OpenSnapshotStreamRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x66\n\nparameters\x18\x02 \x01(\x0b\x32R.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.SnapshotStreamParameters\"0\n\x1aOpenSnapshotStreamResponse\x12\x12\n\ntopic_name\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.srv.open_snapshot_stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OPENSNAPSHOTSTREAMREQUEST']._serialized_start=237
  _globals['_OPENSNAPSHOTSTREAMREQUEST']._serialized_end=388
  _globals['_OPENSNAPSHOTSTREAMRESPONSE']._serialized_start=390
  _globals['_OPENSNAPSHOTSTREAMRESPONSE']._serialized_end=438
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Snapshot(_message.Message):
    __slots__ = ("timestamp_nsec", "schema_hash", "active_mask", "payload")
    TIMESTAMP_NSEC_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_HASH_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_MASK_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    timestamp_nsec: int
    schema_hash: int
    active_mask: _containers.RepeatedScalarFieldContainer[int]
    payload: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, timestamp_nsec: _Optional[int] = ..., schema_hash: _Optional[int] = ..., active_mask: _Optional[_Iterable[int]] = ..., payload: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HmsInfoMsg(_message.Message):
    __slots__ = ("header", "error_code", "component_index", "error_level", "ground_info", "fly_info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    COMPONENT_INDEX_FIELD_NUMBER: _ClassVar[int]
    ERROR_LEVEL_FIELD_NUMBER: _ClassVar[int]
    GROUND_INFO_FIELD_NUMBER: _ClassVar[int]
    FLY_INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    error_code: int
    component_index: int
    error_level: int
    ground_info: str
    fly_info: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., error_code: _Optional[int] = ..., component_index: _Optional[int] = ..., error_level: _Optional[int] = ..., ground_info: _Optional[str] = ..., fly_info: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/esf_raw.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ublox_msgs.msg import esf_raw_block_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__msgs_dot_msg_dot_esf__raw__block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/ublox_msgs/msg/esf_raw.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\x1a=make87_messages_ros2/jazzy/ublox_msgs/msg/esf_raw_block.proto\"c\n\x06\x45sfRAW\x12\x11\n\treserved0\x18\x01 \x03(\r\x12\x46\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.ublox_msgs.msg.EsfRAWBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.esf_raw_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESFRAW']._serialized_start=165
  _globals['_ESFRAW']._serialized_end=264
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/get_cartesian_path.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import constraints_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_constraints__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__state__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import robot_trajectory_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_robot__trajectory__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/moveit_msgs/srv/get_cartesian_path.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/constraints.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/move_it_error_codes.proto\x1a=make87_messages_ros2/humble/moveit_msgs/msg/robot_state.proto\x1a\x42make87_messages_ros2/humble/moveit_msgs/msg/robot_trajectory.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb7\x05\n\x17GetCartesianPathRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12L\n\x0bstart_state\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12\x12\n\ngroup_name\x18\x04 \x01(\t\x12\x11\n\tlink_name\x18\x05 \x01(\t\x12\x46\n\twaypoints\x18\x06 \x03(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x10\n\x08max_step\x18\x07 \x01(\x01\x12\x16\n\x0ejump_threshold\x18\x08 \x01(\x01\x12 \n\x18prismatic_jump_threshold\x18\t \x01(\x01\x12\x1f\n\x17revolute_jump_threshold\x18\n \x01(\x01\x12\x18\n\x10\x61void_collisions\x18\x0b \x01(\x08\x12R\n\x10path_constraints\x18\x0c \x01(\x0b\x32\x38.make87_messages_ros2.humble.moveit_msgs.msg.Constraints\x12#\n\x1bmax_velocity_scaling_factor\x18\r \x01(\x01\x12\'\n\x1fmax_acceleration_scaling_factor\x18\x0e \x01(\x01\x12$\n\x1c\x63\x61rtesian_speed_limited_link\x18\x0f \x01(\t\x12\x1b\n\x13max_cartesian_speed\x18\x10 \x01(\x01\"\xcb\x02\n\x18GetCartesianPathResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12L\n\x0bstart_state\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.moveit_msgs.msg.RobotState\x12N\n\x08solution\x18\x03 \x01(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.RobotTrajectory\x12\x10\n\x08\x66raction\x18\x04 \x01(\x01\x12Q\n\nerror_code\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.humble.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.get_cartesian_path_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETCARTESIANPATHREQUEST']._serialized_start=531
  _globals['_GETCARTESIANPATHREQUEST']._serialized_end=1226
  _globals['_GETCARTESIANPATHRESPONSE']._serialized_start=1229
  _globals['_GETCARTESIANPATHRESPONSE']._serialized_end=1560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/cleanup_local_grids.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rtabmap_msgs/srv/cleanup_local_grids.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\"@\n\x18\x43leanupLocalGridsRequest\x12\x0e\n\x06radius\x18\x01 \x01(\x05\x12\x14\n\x0c\x66ilter_scans\x18\x02 \x01(\x08\"-\n\x19\x43leanupLocalGridsResponse\x12\x10\n\x08modified\x18\x01 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.cleanup_local_grids_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CLEANUPLOCALGRIDSREQUEST']._serialized_start=118
  _globals['_CLEANUPLOCALGRIDSREQUEST']._serialized_end=182
  _globals['_CLEANUPLOCALGRIDSRESPONSE']._serialized_start=184
  _globals['_CLEANUPLOCALGRIDSRESPONSE']._serialized_end=229
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_pb2 as _twist_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PackageUnPickRequest(_message.Message):
    __slots__ = ("header", "enable", "speed_limit")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    SPEED_LIMIT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    enable: bool
    speed_limit: _twist_pb2.Twist
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., enable: bool = ..., speed_limit: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ...) -> None: ...

class PackageUnPickResponse(_message.Message):
    __slots__ = ("header", "success")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as _pose_with_covariance_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import twist_with_covariance_pb2 as _twist_with_covariance_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrackedObject(_message.Message):
    __slots__ = ("header", "id", "pose", "velocity", "linear_acceleration", "linear_acceleration_covariance", "polygon", "length", "length_quality", "width", "width_quality", "classification", "classification_quality", "existence_probability", "age_duration", "prediction_duration", "active")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    LINEAR_ACCELERATION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    LENGTH_QUALITY_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    WIDTH_QUALITY_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_QUALITY_FIELD_NUMBER: _ClassVar[int]
    EXISTENCE_PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    AGE_DURATION_FIELD_NUMBER: _ClassVar[int]
    PREDICTION_DURATION_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    pose: _pose_with_covariance_pb2.PoseWithCovariance
    velocity: _twist_with_covariance_pb2.TwistWithCovariance
    linear_acceleration: _vector3_pb2.Vector3
    linear_acceleration_covariance: _containers.RepeatedScalarFieldContainer[float]
    polygon: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    length: float
    length_quality: float
    width: float
    width_quality: float
    classification: int
    classification_quality: float
    existence_probability: float
    age_duration: _duration_pb2.Duration
    prediction_duration: _duration_pb2.Duration
    active: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., pose: _Optional[_Union[_pose_with_covariance_pb2.PoseWithCovariance, _Mapping]] = ..., velocity: _Optional[_Union[_twist_with_covariance_pb2.TwistWithCovariance, _Mapping]] = ..., linear_acceleration: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., linear_acceleration_covariance: _Optional[_Iterable[float]] = ..., polygon: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., length: _Optional[float] = ..., length_quality: _Optional[float] = ..., width: _Optional[float] = ..., width_quality: _Optional[float] = ..., classification: _Optional[int] = ..., classification_quality: _Optional[float] = ..., existence_probability: _Optional[float] = ..., age_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., prediction_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., active: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/nav_dgps.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ublox_msgs.msg import nav_dgpssv_pb2 as make87__messages__ros2_dot_humble_dot_ublox__msgs_dot_msg_dot_nav__dgpssv__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/humble/ublox_msgs/msg/nav_dgps.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/ublox_msgs/msg/nav_dgpssv.proto\"\xef\x01\n\x07NavDGPS\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05i_tow\x18\x02 \x01(\r\x12\x0b\n\x03\x61ge\x18\x03 \x01(\x05\x12\x0f\n\x07\x62\x61se_id\x18\x04 \x01(\x05\x12\x13\n\x0b\x62\x61se_health\x18\x05 \x01(\x05\x12\x0e\n\x06num_ch\x18\x06 \x01(\x05\x12\x0e\n\x06status\x18\x07 \x01(\r\x12\x11\n\treserved1\x18\x08 \x01(\r\x12\x41\n\x02sv\x18\t \x03(\x0b\x32\x35.make87_messages_ros2.humble.ublox_msgs.msg.NavDGPSSVb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.nav_dgps_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVDGPS']._serialized_start=202
  _globals['_NAVDGPS']._serialized_end=441
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_introspection_msgs/msg/topic_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/marti_introspection_msgs/msg/topic_info.proto\x12\x39make87_messages_ros2.rolling.marti_introspection_msgs.msg\"~\n\tTopicInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rresolved_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05group\x18\x04 \x01(\t\x12\x14\n\x0cmessage_type\x18\x05 \x01(\t\x12\x12\n\nadvertised\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_introspection_msgs.msg.topic_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TOPICINFO']._serialized_start=137
  _globals['_TOPICINFO']._serialized_end=263
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SoftwareRevisionRpt(_message.Message):
    __slots__ = ("header", "software_version_0", "software_version_1", "software_version_2", "software_day", "software_month_year")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_VERSION_0_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_VERSION_1_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_VERSION_2_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_DAY_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_MONTH_YEAR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    software_version_0: int
    software_version_1: int
    software_version_2: int
    software_day: int
    software_month_year: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., software_version_0: _Optional[int] = ..., software_version_1: _Optional[int] = ..., software_version_2: _Optional[int] = ..., software_day: _Optional[int] = ..., software_month_year: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ReviveTaskRequest(_message.Message):
    __slots__ = ("requester", "task_id")
    REQUESTER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    requester: str
    task_id: str
    def __init__(self, requester: _Optional[str] = ..., task_id: _Optional[str] = ...) -> None: ...

class ReviveTaskResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetGoalRequest(_message.Message):
    __slots__ = ("node_id", "node_label", "frame_id")
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    NODE_LABEL_FIELD_NUMBER: _ClassVar[int]
    FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    node_label: str
    frame_id: str
    def __init__(self, node_id: _Optional[int] = ..., node_label: _Optional[str] = ..., frame_id: _Optional[str] = ...) -> None: ...

class SetGoalResponse(_message.Message):
    __slots__ = ("path_ids", "path_poses", "planning_time")
    PATH_IDS_FIELD_NUMBER: _ClassVar[int]
    PATH_POSES_FIELD_NUMBER: _ClassVar[int]
    PLANNING_TIME_FIELD_NUMBER: _ClassVar[int]
    path_ids: _containers.RepeatedScalarFieldContainer[int]
    path_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    planning_time: float
    def __init__(self, path_ids: _Optional[_Iterable[int]] = ..., path_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., planning_time: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LogRequestDataRequest(_message.Message):
    __slots__ = ("id", "offset", "count")
    ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    id: int
    offset: int
    count: int
    def __init__(self, id: _Optional[int] = ..., offset: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...

class LogRequestDataResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.mavros_msgs.msg import position_target_pb2 as _position_target_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Trajectory(_message.Message):
    __slots__ = ("header", "type", "point_1", "point_2", "point_3", "point_4", "point_5", "point_valid", "command", "time_horizon")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    POINT_1_FIELD_NUMBER: _ClassVar[int]
    POINT_2_FIELD_NUMBER: _ClassVar[int]
    POINT_3_FIELD_NUMBER: _ClassVar[int]
    POINT_4_FIELD_NUMBER: _ClassVar[int]
    POINT_5_FIELD_NUMBER: _ClassVar[int]
    POINT_VALID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    TIME_HORIZON_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    type: int
    point_1: _position_target_pb2.PositionTarget
    point_2: _position_target_pb2.PositionTarget
    point_3: _position_target_pb2.PositionTarget
    point_4: _position_target_pb2.PositionTarget
    point_5: _position_target_pb2.PositionTarget
    point_valid: _containers.RepeatedScalarFieldContainer[int]
    command: _containers.RepeatedScalarFieldContainer[int]
    time_horizon: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., type: _Optional[int] = ..., point_1: _Optional[_Union[_position_target_pb2.PositionTarget, _Mapping]] = ..., point_2: _Optional[_Union[_position_target_pb2.PositionTarget, _Mapping]] = ..., point_3: _Optional[_Union[_position_target_pb2.PositionTarget, _Mapping]] = ..., point_4: _Optional[_Union[_position_target_pb2.PositionTarget, _Mapping]] = ..., point_5: _Optional[_Union[_position_target_pb2.PositionTarget, _Mapping]] = ..., point_valid: _Optional[_Iterable[int]] = ..., command: _Optional[_Iterable[int]] = ..., time_horizon: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mapviz_interfaces/srv/add_mapviz_display.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.marti_common_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_jazzy_dot_marti__common__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/mapviz_interfaces/srv/add_mapviz_display.proto\x12\x30make87_messages_ros2.jazzy.mapviz_interfaces.srv\x1a@make87_messages_ros2/jazzy/marti_common_msgs/msg/key_value.proto\"\xaa\x01\n\x17\x41\x64\x64MapvizDisplayRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\ndraw_order\x18\x03 \x01(\x05\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12N\n\nproperties\x18\x05 \x03(\x0b\x32:.make87_messages_ros2.jazzy.marti_common_msgs.msg.KeyValue\"<\n\x18\x41\x64\x64MapvizDisplayResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mapviz_interfaces.srv.add_mapviz_display_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDMAPVIZDISPLAYREQUEST']._serialized_start=194
  _globals['_ADDMAPVIZDISPLAYREQUEST']._serialized_end=364
  _globals['_ADDMAPVIZDISPLAYRESPONSE']._serialized_start=366
  _globals['_ADDMAPVIZDISPLAYRESPONSE']._serialized_end=426
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.autoware_perception_msgs.msg import traffic_signal_element_pb2 as _traffic_signal_element_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficSignal(_message.Message):
    __slots__ = ("traffic_signal_id", "elements")
    TRAFFIC_SIGNAL_ID_FIELD_NUMBER: _ClassVar[int]
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    traffic_signal_id: int
    elements: _containers.RepeatedCompositeFieldContainer[_traffic_signal_element_pb2.TrafficSignalElement]
    def __init__(self, traffic_signal_id: _Optional[int] = ..., elements: _Optional[_Iterable[_Union[_traffic_signal_element_pb2.TrafficSignalElement, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgNMEA6(_message.Message):
    __slots__ = ("filter", "version", "num_sv", "flags")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    filter: int
    version: int
    num_sv: int
    flags: int
    def __init__(self, filter: _Optional[int] = ..., version: _Optional[int] = ..., num_sv: _Optional[int] = ..., flags: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RightFootLed(_message.Message):
    __slots__ = ("color",)
    COLOR_FIELD_NUMBER: _ClassVar[int]
    color: _color_rgba_pb2.ColorRGBA
    def __init__(self, color: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RxmRTCM(_message.Message):
    __slots__ = ("version", "flags", "reserved0", "ref_station", "msg_type")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    REF_STATION_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_FIELD_NUMBER: _ClassVar[int]
    version: int
    flags: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    ref_station: int
    msg_type: int
    def __init__(self, version: _Optional[int] = ..., flags: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ..., ref_station: _Optional[int] = ..., msg_type: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import link_pb2 as _link_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddLinkRequest(_message.Message):
    __slots__ = ("header", "link")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LINK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    link: _link_pb2.Link
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., link: _Optional[_Union[_link_pb2.Link, _Mapping]] = ...) -> None: ...

class AddLinkResponse(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RangeInformation(_message.Message):
    __slots__ = ("prn_number", "glofreq", "psr", "psr_std", "adr", "adr_std", "dopp", "noise_density_ratio", "locktime", "tracking_status")
    PRN_NUMBER_FIELD_NUMBER: _ClassVar[int]
    GLOFREQ_FIELD_NUMBER: _ClassVar[int]
    PSR_FIELD_NUMBER: _ClassVar[int]
    PSR_STD_FIELD_NUMBER: _ClassVar[int]
    ADR_FIELD_NUMBER: _ClassVar[int]
    ADR_STD_FIELD_NUMBER: _ClassVar[int]
    DOPP_FIELD_NUMBER: _ClassVar[int]
    NOISE_DENSITY_RATIO_FIELD_NUMBER: _ClassVar[int]
    LOCKTIME_FIELD_NUMBER: _ClassVar[int]
    TRACKING_STATUS_FIELD_NUMBER: _ClassVar[int]
    prn_number: int
    glofreq: int
    psr: float
    psr_std: float
    adr: float
    adr_std: float
    dopp: float
    noise_density_ratio: float
    locktime: float
    tracking_status: int
    def __init__(self, prn_number: _Optional[int] = ..., glofreq: _Optional[int] = ..., psr: _Optional[float] = ..., psr_std: _Optional[float] = ..., adr: _Optional[float] = ..., adr_std: _Optional[float] = ..., dopp: _Optional[float] = ..., noise_density_ratio: _Optional[float] = ..., locktime: _Optional[float] = ..., tracking_status: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mrpt_nav_interfaces/msg/georeferencing_metadata.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/mrpt_nav_interfaces/msg/georeferencing_metadata.proto\x12\x34make87_messages_ros2.rolling.mrpt_nav_interfaces.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\"\xa6\x02\n\x16GeoreferencingMetadata\x12\r\n\x05valid\x18\x01 \x01(\x08\x12X\n\x0ct_enu_to_map\x18\x02 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovariance\x12J\n\x0ct_enu_to_utm\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x0e\n\x06height\x18\x06 \x01(\x01\x12\x10\n\x08utm_zone\x18\x07 \x01(\x05\x12\x10\n\x08utm_band\x18\x08 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mrpt_nav_interfaces.msg.georeferencing_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GEOREFERENCINGMETADATA']._serialized_start=275
  _globals['_GEOREFERENCINGMETADATA']._serialized_end=569
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/srv/control_world.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ros_gz_interfaces.msg import world_control_pb2 as make87__messages__ros2_dot_rolling_dot_ros__gz__interfaces_dot_msg_dot_world__control__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/ros_gz_interfaces/srv/control_world.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.srv\x1a\x46make87_messages_ros2/rolling/ros_gz_interfaces/msg/world_control.proto\"n\n\x13\x43ontrolWorldRequest\x12W\n\rworld_control\x18\x01 \x01(\x0b\x32@.make87_messages_ros2.rolling.ros_gz_interfaces.msg.WorldControl\"\'\n\x14\x43ontrolWorldResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.srv.control_world_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTROLWORLDREQUEST']._serialized_start=198
  _globals['_CONTROLWORLDREQUEST']._serialized_end=308
  _globals['_CONTROLWORLDRESPONSE']._serialized_start=310
  _globals['_CONTROLWORLDRESPONSE']._serialized_end=349
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rmf_reservation_msgs.msg import ticket_pb2 as _ticket_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReleaseRequest(_message.Message):
    __slots__ = ("ticket", "location")
    TICKET_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    ticket: _ticket_pb2.Ticket
    location: str
    def __init__(self, ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ..., location: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/set_link_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.gazebo_msgs.msg import link_state_pb2 as make87__messages__ros2_dot_jazzy_dot_gazebo__msgs_dot_msg_dot_link__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/gazebo_msgs/srv/set_link_state.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a;make87_messages_ros2/jazzy/gazebo_msgs/msg/link_state.proto\"`\n\x13SetLinkStateRequest\x12I\n\nlink_state\x18\x01 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.gazebo_msgs.msg.LinkState\"?\n\x14SetLinkStateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.set_link_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETLINKSTATEREQUEST']._serialized_start=172
  _globals['_SETLINKSTATEREQUEST']._serialized_end=268
  _globals['_SETLINKSTATERESPONSE']._serialized_start=270
  _globals['_SETLINKSTATERESPONSE']._serialized_end=333
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/attached_collision_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/moveit_msgs/msg/attached_collision_object.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x41make87_messages_ros2/jazzy/moveit_msgs/msg/collision_object.proto\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\"\xf7\x01\n\x17\x41ttachedCollisionObject\x12\x11\n\tlink_name\x18\x01 \x01(\t\x12K\n\x06object\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.jazzy.moveit_msgs.msg.CollisionObject\x12\x13\n\x0btouch_links\x18\x03 \x03(\t\x12W\n\x0e\x64\x65tach_posture\x18\x04 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12\x0e\n\x06weight\x18\x05 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.attached_collision_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ATTACHEDCOLLISIONOBJECT']._serialized_start=261
  _globals['_ATTACHEDCOLLISIONOBJECT']._serialized_end=508
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nicla_vision_ros2/msg/audio_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/nicla_vision_ros2/msg/audio_data.proto\x12\x30make87_messages_ros2.jazzy.nicla_vision_ros2.msg\"\x19\n\tAudioData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nicla_vision_ros2.msg.audio_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_AUDIODATA']._serialized_start=119
  _globals['_AUDIODATA']._serialized_end=144
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/psdk_interfaces/msg/gps_details.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/psdk_interfaces/msg/gps_details.proto\x12/make87_messages_ros2.humble.psdk_interfaces.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x90\x03\n\nGPSDetails\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x16\n\x0ehorizontal_dop\x18\x03 \x01(\x02\x12\x14\n\x0cposition_dop\x18\x04 \x01(\x02\x12\x11\n\tfix_state\x18\x05 \x01(\x02\x12\x19\n\x11vertical_accuracy\x18\x06 \x01(\x02\x12\x1b\n\x13horizontal_accuracy\x18\x07 \x01(\x02\x12\x16\n\x0espeed_accuracy\x18\x08 \x01(\x02\x12\x1f\n\x17num_gps_satellites_used\x18\t \x01(\r\x12#\n\x1bnum_glonass_satellites_used\x18\n \x01(\r\x12!\n\x19num_total_satellites_used\x18\x0b \x01(\r\x12\x13\n\x0bgps_counter\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.psdk_interfaces.msg.gps_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GPSDETAILS']._serialized_start=209
  _globals['_GPSDETAILS']._serialized_end=609
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_extended_solution_status_pb2 as _novatel_extended_solution_status_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_signal_mask_pb2 as _novatel_signal_mask_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelDualAntennaHeading(_message.Message):
    __slots__ = ("header", "ros2_header", "novatel_msg_header", "solution_status", "position_type", "baseline_length", "heading", "pitch", "heading_sigma", "pitch_sigma", "station_id", "num_satellites_tracked", "num_satellites_used_in_solution", "num_satellites_above_elevation_mask_angle", "num_satellites_above_elevation_mask_angle_l2", "solution_source", "extended_solution_status", "signal_mask")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    POSITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    BASELINE_LENGTH_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    HEADING_SIGMA_FIELD_NUMBER: _ClassVar[int]
    PITCH_SIGMA_FIELD_NUMBER: _ClassVar[int]
    STATION_ID_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_TRACKED_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_ABOVE_ELEVATION_MASK_ANGLE_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_ABOVE_ELEVATION_MASK_ANGLE_L2_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_SOURCE_FIELD_NUMBER: _ClassVar[int]
    EXTENDED_SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_MASK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    solution_status: str
    position_type: str
    baseline_length: float
    heading: float
    pitch: float
    heading_sigma: float
    pitch_sigma: float
    station_id: str
    num_satellites_tracked: int
    num_satellites_used_in_solution: int
    num_satellites_above_elevation_mask_angle: int
    num_satellites_above_elevation_mask_angle_l2: int
    solution_source: int
    extended_solution_status: _novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus
    signal_mask: _novatel_signal_mask_pb2.NovatelSignalMask
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., solution_status: _Optional[str] = ..., position_type: _Optional[str] = ..., baseline_length: _Optional[float] = ..., heading: _Optional[float] = ..., pitch: _Optional[float] = ..., heading_sigma: _Optional[float] = ..., pitch_sigma: _Optional[float] = ..., station_id: _Optional[str] = ..., num_satellites_tracked: _Optional[int] = ..., num_satellites_used_in_solution: _Optional[int] = ..., num_satellites_above_elevation_mask_angle: _Optional[int] = ..., num_satellites_above_elevation_mask_angle_l2: _Optional[int] = ..., solution_source: _Optional[int] = ..., extended_solution_status: _Optional[_Union[_novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus, _Mapping]] = ..., signal_mask: _Optional[_Union[_novatel_signal_mask_pb2.NovatelSignalMask, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/tf2_msgs/srv/frame_graph.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/tf2_msgs/srv/frame_graph.proto\x12\'make87_messages_ros2.jazzy.tf2_msgs.srv\"\x13\n\x11\x46rameGraphRequest\"(\n\x12\x46rameGraphResponse\x12\x12\n\nframe_yaml\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.tf2_msgs.srv.frame_graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FRAMEGRAPHREQUEST']._serialized_start=102
  _globals['_FRAMEGRAPHREQUEST']._serialized_end=121
  _globals['_FRAMEGRAPHRESPONSE']._serialized_start=123
  _globals['_FRAMEGRAPHRESPONSE']._serialized_end=163
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccContainerStatus(_message.Message):
    __slots__ = ("header", "path", "initial_states", "active_states", "local_data", "info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    INITIAL_STATES_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_STATES_FIELD_NUMBER: _ClassVar[int]
    LOCAL_DATA_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    path: str
    initial_states: _containers.RepeatedScalarFieldContainer[str]
    active_states: _containers.RepeatedScalarFieldContainer[str]
    local_data: str
    info: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., path: _Optional[str] = ..., initial_states: _Optional[_Iterable[str]] = ..., active_states: _Optional[_Iterable[str]] = ..., local_data: _Optional[str] = ..., info: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/scenario_execution_interfaces/srv/execute_scenario.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.scenario_execution_interfaces.msg import scenario_pb2 as make87__messages__ros2_dot_jazzy_dot_scenario__execution__interfaces_dot_msg_dot_scenario__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/scenario_execution_interfaces/srv/execute_scenario.proto\x12<make87_messages_ros2.jazzy.scenario_execution_interfaces.srv\x1aKmake87_messages_ros2/jazzy/scenario_execution_interfaces/msg/scenario.proto\"r\n\x16\x45xecuteScenarioRequest\x12X\n\x08scenario\x18\x01 \x01(\x0b\x32\x46.make87_messages_ros2.jazzy.scenario_execution_interfaces.msg.Scenario\")\n\x17\x45xecuteScenarioResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.scenario_execution_interfaces.srv.execute_scenario_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EXECUTESCENARIOREQUEST']._serialized_start=226
  _globals['_EXECUTESCENARIOREQUEST']._serialized_end=340
  _globals['_EXECUTESCENARIORESPONSE']._serialized_start=342
  _globals['_EXECUTESCENARIORESPONSE']._serialized_end=383
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import error_pb2 as _error_pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import feature_module_pb2 as _feature_module_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FeatureIntGetRequest(_message.Message):
    __slots__ = ("header", "feature_name", "feature_module")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FEATURE_NAME_FIELD_NUMBER: _ClassVar[int]
    FEATURE_MODULE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    feature_name: str
    feature_module: _feature_module_pb2.FeatureModule
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., feature_name: _Optional[str] = ..., feature_module: _Optional[_Union[_feature_module_pb2.FeatureModule, _Mapping]] = ...) -> None: ...

class FeatureIntGetResponse(_message.Message):
    __slots__ = ("header", "value", "error")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    value: int
    error: _error_pb2.Error
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., value: _Optional[int] = ..., error: _Optional[_Union[_error_pb2.Error, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_rawx.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import rawx_data_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_rawx__data__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import rec_stat_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_rec__stat__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_rxm_rawx.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a=make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/rawx_data.proto\x1a<make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/rec_stat.proto\"\xb5\x02\n\nUBXRxmRawx\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07rcv_tow\x18\x02 \x01(\x01\x12\x0c\n\x04week\x18\x03 \x01(\r\x12\x0e\n\x06leap_s\x18\x04 \x01(\x05\x12\x10\n\x08num_meas\x18\x05 \x01(\r\x12H\n\x08rec_stat\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.RecStat\x12\x0f\n\x07version\x18\x07 \x01(\r\x12J\n\trawx_data\x18\x08 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.RawxDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_rxm_rawx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXRXMRAWX']._serialized_start=295
  _globals['_UBXRXMRAWX']._serialized_end=604
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/node_details.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/rosapi_msgs/srv/node_details.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\"\"\n\x12NodeDetailsRequest\x12\x0c\n\x04node\x18\x01 \x01(\t\"P\n\x13NodeDetailsResponse\x12\x13\n\x0bsubscribing\x18\x01 \x03(\t\x12\x12\n\npublishing\x18\x02 \x03(\t\x12\x10\n\x08services\x18\x03 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.node_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NODEDETAILSREQUEST']._serialized_start=113
  _globals['_NODEDETAILSREQUEST']._serialized_end=147
  _globals['_NODEDETAILSRESPONSE']._serialized_start=149
  _globals['_NODEDETAILSRESPONSE']._serialized_end=229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/septentrio_gnss_driver/msg/meas_epoch_channel_type1.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import meas_epoch_channel_type2_pb2 as make87__messages__ros2_dot_jazzy_dot_septentrio__gnss__driver_dot_msg_dot_meas__epoch__channel__type2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/meas_epoch_channel_type1.proto\x12\x35make87_messages_ros2.jazzy.septentrio_gnss_driver.msg\x1aTmake87_messages_ros2/jazzy/septentrio_gnss_driver/msg/meas_epoch_channel_type2.proto\"\xbe\x02\n\x15MeasEpochChannelType1\x12\x12\n\nrx_channel\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\r\n\x05sv_id\x18\x03 \x01(\r\x12\x0c\n\x04misc\x18\x04 \x01(\r\x12\x10\n\x08\x63ode_lsb\x18\x05 \x01(\r\x12\x0f\n\x07\x64oppler\x18\x06 \x01(\x05\x12\x13\n\x0b\x63\x61rrier_lsb\x18\x07 \x01(\r\x12\x13\n\x0b\x63\x61rrier_msb\x18\x08 \x01(\x05\x12\x0b\n\x03\x63n0\x18\t \x01(\r\x12\x11\n\tlock_time\x18\n \x01(\r\x12\x10\n\x08obs_info\x18\x0b \x01(\r\x12\n\n\x02n2\x18\x0c \x01(\r\x12[\n\x05type2\x18\r \x03(\x0b\x32L.make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.MeasEpochChannelType2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.septentrio_gnss_driver.msg.meas_epoch_channel_type1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MEASEPOCHCHANNELTYPE1']._serialized_start=230
  _globals['_MEASEPOCHCHANNELTYPE1']._serialized_end=548
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import charging_assignment_pb2 as _charging_assignment_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ChargingAssignments(_message.Message):
    __slots__ = ("fleet_name", "assignments")
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    fleet_name: str
    assignments: _containers.RepeatedCompositeFieldContainer[_charging_assignment_pb2.ChargingAssignment]
    def __init__(self, fleet_name: _Optional[str] = ..., assignments: _Optional[_Iterable[_Union[_charging_assignment_pb2.ChargingAssignment, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/key_point.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point2f_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_point2f__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/rtabmap_msgs/msg/key_point.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a\x39make87_messages_ros2/jazzy/rtabmap_msgs/msg/point2f.proto\"\x9d\x01\n\x08KeyPoint\x12@\n\x02pt\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Point2f\x12\x0c\n\x04size\x18\x02 \x01(\x02\x12\r\n\x05\x61ngle\x18\x03 \x01(\x02\x12\x10\n\x08response\x18\x04 \x01(\x02\x12\x0e\n\x06octave\x18\x05 \x01(\x05\x12\x10\n\x08\x63lass_id\x18\x06 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.key_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_KEYPOINT']._serialized_start=168
  _globals['_KEYPOINT']._serialized_end=325
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_charger_msgs/msg/charger_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rmf_charger_msgs/msg/charger_state.proto\x12\x31make87_messages_ros2.rolling.rmf_charger_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"\xb6\x02\n\x0c\x43hargerState\x12O\n\x0c\x63harger_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\r\n\x05state\x18\x02 \x01(\r\x12\x14\n\x0c\x63harger_name\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x12\n\nrequest_id\x18\x05 \x01(\t\x12\x13\n\x0brobot_fleet\x18\x06 \x01(\t\x12\x12\n\nrobot_name\x18\x07 \x01(\t\x12\\\n\x15time_to_fully_charged\x18\x08 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_charger_msgs.msg.charger_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CHARGERSTATE']._serialized_start=257
  _globals['_CHARGERSTATE']._serialized_end=567
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ROIObservationResultData(_message.Message):
    __slots__ = ("header", "task_result", "result_safe", "result_valid", "distance_valid", "distance_safe")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TASK_RESULT_FIELD_NUMBER: _ClassVar[int]
    RESULT_SAFE_FIELD_NUMBER: _ClassVar[int]
    RESULT_VALID_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_VALID_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_SAFE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    task_result: int
    result_safe: int
    result_valid: int
    distance_valid: int
    distance_safe: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., task_result: _Optional[int] = ..., result_safe: _Optional[int] = ..., result_valid: _Optional[int] = ..., distance_valid: _Optional[int] = ..., distance_safe: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_scheduler_msgs/srv/list_schedules.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg import schedule_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__scheduler__msgs_dot_msg_dot_schedule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/rmf_scheduler_msgs/srv/list_schedules.proto\x12\x31make87_messages_ros2.jazzy.rmf_scheduler_msgs.srv\x1a@make87_messages_ros2/jazzy/rmf_scheduler_msgs/msg/schedule.proto\"-\n\x14ListSchedulesRequest\x12\x15\n\rcreated_after\x18\x01 \x01(\x03\"\x89\x01\n\x15ListSchedulesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12N\n\tschedules\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg.Scheduleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_scheduler_msgs.srv.list_schedules_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LISTSCHEDULESREQUEST']._serialized_start=191
  _globals['_LISTSCHEDULESREQUEST']._serialized_end=236
  _globals['_LISTSCHEDULESRESPONSE']._serialized_start=239
  _globals['_LISTSCHEDULESRESPONSE']._serialized_end=376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/realsense2_camera_msgs/msg/rgbd.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_camera__info__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/realsense2_camera_msgs/msg/rgbd.proto\x12\x36make87_messages_ros2.humble.realsense2_camera_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto\x1a\x37make87_messages_ros2/humble/sensor_msgs/msg/image.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xa5\x03\n\x04RGBD\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12P\n\x0frgb_camera_info\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.humble.sensor_msgs.msg.CameraInfo\x12R\n\x11\x64\x65pth_camera_info\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.humble.sensor_msgs.msg.CameraInfo\x12?\n\x03rgb\x18\x05 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Image\x12\x41\n\x05\x64\x65pth\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.realsense2_camera_msgs.msg.rgbd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RGBD']._serialized_start=336
  _globals['_RGBD']._serialized_end=757
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.marti_nav_msgs.msg import route_position_pb2 as _route_position_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RouteOffset(_message.Message):
    __slots__ = ("header", "relative_pose", "route_position")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_POSE_FIELD_NUMBER: _ClassVar[int]
    ROUTE_POSITION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    relative_pose: _pose_pb2.Pose
    route_position: _route_position_pb2.RoutePosition
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., relative_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., route_position: _Optional[_Union[_route_position_pb2.RoutePosition, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.nav2_msgs.msg import behavior_tree_status_change_pb2 as _behavior_tree_status_change_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviorTreeLog(_message.Message):
    __slots__ = ("header", "timestamp", "event_log")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    EVENT_LOG_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    timestamp: _time_pb2.Time
    event_log: _containers.RepeatedCompositeFieldContainer[_behavior_tree_status_change_pb2.BehaviorTreeStatusChange]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., event_log: _Optional[_Iterable[_Union[_behavior_tree_status_change_pb2.BehaviorTreeStatusChange, _Mapping]]] = ...) -> None: ...
